@@ -2177,6 +2177,7 @@ class Imagen(nn.Module):
         cond_video_frames = None,
         post_cond_video_frames = None,
         inpaint_images = None,
+        inpaint_videos = None,
         inpaint_masks = None,
         inpaint_resample_times = 5,
         init_images = None,
@@ -2208,13 +2209,15 @@ class Imagen(nn.Module):
 
         # prepare inpainting
 
+        inpaint_images = default(inpaint_videos, inpaint_images)
+
         has_inpainting = exists(inpaint_images) and exists(inpaint_masks)
         resample_times = inpaint_resample_times if has_inpainting else 1
 
         if has_inpainting:
             inpaint_images = self.normalize_img(inpaint_images)
             inpaint_images = self.resize_to(inpaint_images, shape[-1], **resize_kwargs)
-            inpaint_masks = self.resize_to(rearrange(inpaint_masks, 'b ... -> b 1 ...').float(), shape[-1]).bool()
+            inpaint_masks = self.resize_to(rearrange(inpaint_masks, 'b ... -> b 1 ...').float(), shape[-1], **resize_kwargs).bool()
 
         # time
 
@@ -2295,6 +2298,7 @@ class Imagen(nn.Module):
         cond_images = None,
         cond_video_frames = None,
         post_cond_video_frames = None,
+        inpaint_videos = None,
         inpaint_images = None,
         inpaint_masks = None,
         inpaint_resample_times = 5,
@@ -2331,6 +2335,10 @@ class Imagen(nn.Module):
             text_masks = default(text_masks, lambda: torch.any(text_embeds != 0., dim = -1))
             batch_size = text_embeds.shape[0]
 
+        # inpainting
+
+        inpaint_images = default(inpaint_videos, inpaint_images)
+
         if exists(inpaint_images):
             if self.unconditional:
                 if batch_size == 1: # assume researcher wants to broadcast along inpainted images
@@ -2364,9 +2372,9 @@ class Imagen(nn.Module):
             video_frames = inpaint_images.shape[2]
 
             if inpaint_masks.ndim == 3:
-                inpaint_masks = rearrange(inpaint_masks, 'b h w -> b 1 h w')
+                inpaint_masks = repeat(inpaint_masks, 'b h w -> b f h w', f = video_frames)
 
-            assert inpaint_masks.shape[1] == 1, 'for now, inpainting video can only accept a single mask across frames'
+            assert inpaint_masks.shape[1] == video_frames
 
         assert not (self.is_video and not exists(video_frames)), 'video_frames must be passed in on sample time if training on video'
 
